/**
 * @function setupMysql
 */

'use strict'

const execcli = require('execcli')
const co = require('co')
const async = require('async')
const colorprint = require('colorprint')
const assert = require('assert')

/** @lends setupMysql */
function setupMysql (env, options = {}) {
  const ROOT_USERNAME = env.ROOT_USERNAME || process.env.ROOT_USERNAME || 'root'
  const ROOT_PASSWORD = env.ROOT_PASSWORD || process.env.ROOT_PASSWORD || process.env.MYSQL_ROOT_PASSWORD || ''

  const HOST = env.HOST || 'localhost'
  const USERNAME = env.USER || env.USERNAME
  const DATABASE = env.DATABASE || env.SCHEMA
  const PASSWORD = env.PASSWORD;

  let sql = _sql(DATABASE, USERNAME, PASSWORD)

  let cmdBin = 'mysql'
  let cmdArgs = _args(ROOT_USERNAME, HOST, ROOT_PASSWORD, sql)

  return co(function * () {
    colorprint.debug(`  Executing SQL...`)
    colorprint.trace(sql.split(/;\s?/g).join('\n'))
    yield execcli(cmdBin, cmdArgs, {})
    colorprint.debug('  ...SQL done!')
  })
}

function _sql (database, username, password) {
  return `CREATE DATABASE IF NOT EXISTS \`${database}\` DEFAULT CHARACTER SET utf8; GRANT ALL ON \`${database}\`.* TO \`${username}\` IDENTIFIED BY "${password}"`
}

function _args (username, host, password, sql) {
  let args = [
    '-u', username
  ];
  if (host) {
    args = args.concat('-h', host)
  }
  if (password) {
    process.env.MYSQL_PWD = password; //Use MYSQL_PWD to suppress insecure warning.
    //args = args.concat('-p' + password)
  }
  args = args.concat({ 'e': sql })
  return args
}

module.exports = setupMysql
