/**
 * Test case for define.
 * Runs with mocha.
 */

'use strict'

const define = require('../lib/define.js')
const assert = require('assert')
const co = require('co')
const apemandb = require('apemandb')

describe('define', () => {
  let tmpDir = __dirname + '/../tmp'

  function noop () {
  }

  it('Setup sqlite', () => co(function * () {
    let dbFile = tmpDir + '/testing-db.db'
    let db = apemandb({
      env: {
        DATABASE: 'testing-database01',
        USERNAME: "foo",
        PASSWORD: "bar",
        DIALECT: 'sqlite',
        STORAGE: dbFile
      }
    })
    let task = define(db, {})
    assert.ok(task)
    let context = {
      verbose: false,
      logger: {
        info: noop,
        debug: noop,
        trace: noop
      }
    }
    yield task(context)
  }))

  it('Setup mysql', () => co(function * () {
    let db = apemandb({
      env: {
        DATABASE: 'testing-ap-task-setupdb-01',
        PASSWORD: "testing-ap01",
        USERNAME: "testing-ap01",
        DIALECT: 'mysql',
        ROOT_USERNAME: 'root',
        ROOT_PASSWORD: ''
      }
    })
    let task = define(db, {})
    assert.ok(task)
    let context = {
      verbose: false,
      logger: {
        info: noop,
        debug: noop,
        trace: noop
      }
    }
    yield task(context)
  }))
})

/* global describe, before, after, it */
